=======
Credits
=======

Development Lead
----------------

* Scott Triglia <scott.triglia@gmail.com>

Contributors
------------

* Gergely Imreh (imrehg@gmail.com)
* Chris Hepner (chrishepner on Github)
